//! Some commonly used services that implement
//! [`Endpoint`](crate::endpoint::Endpoint).

mod files;

pub use files::Files;
